@@ -22,7 +22,7 @@ You will learn how to create a new Location, a Bucket and an ObjectVersion
 using the programmatic APIs of Invenio-Files-REST.
 
 First, you will have to setup your virtualenv environment and install
-this module. You can follow the same steps as in :doc:`exampleapp`.
+this module along with all it's dependencies.
 
 After that, start a Python shell and execute the following commands:
 
@@ -121,7 +121,7 @@ Create objects
 Files are represented by ObjectVersions. After creating a bucket, you can now
 add files to it, for example:
 
->>> from six import BytesIO
+>>> from io import BytesIO
 >>> from invenio_files_rest.models import ObjectVersion
 >>> a_file = BytesIO(b"my file contents")
 >>> f = ObjectVersion.create(b1, "thesis.pdf", stream=a_file)
@@ -248,8 +248,9 @@ This is because they depend on your physical file storage infrastructure.
 You will have to create them in advance when setting up your Invenio
 instance.
 
-To be able to run each of the next steps, you can start the example app
-as described in :doc:`exampleapp`.
+To be able to run each of the next steps, you can instantiate and start an
+Invenio instance as described `here
+<https://invenio.readthedocs.io/en/latest/quickstart/quickstart.html#create-an-invenio-instance>`_.
 
 Create a bucket
 ^^^^^^^^^^^^^^^
@@ -386,6 +387,17 @@ APIs reference documentation below for more information.
 Be aware that there are security implications to take into account when
 serving files. See the :ref:`usage-security` for more information.
 
+Invenio-Files-Rest provides also the functionality to serve your files directly
+from your external storage. This is achieved by attaching the
+`X-Accel-Redirect
+<https://www.nginx.com/resources/wiki/start/topics/examples/x-accel/>`_
+header to the response, which will then be redirected by
+your Web Proxy (e.g. NGINX, Apache) to your external storage, finally streaming
+the file directly to the user.
+To use this feature you will need to configure your Web Proxy accordingly and
+then enable the
+:py:data:`invenio_files_rest.config.FILES_REST_XSENDFILE_ENABLED`.
+
 API Reference
 ^^^^^^^^^^^^^
 
@@ -957,8 +969,6 @@ a reference to the old :code:`FileInstance` to reference the new
 :code:`FileInstance` and eventually run an integrity check.
 """
 
-from __future__ import absolute_import, print_function
-
 from .ext import InvenioFilesREST
 from .proxies import current_files_rest
 from .version import __version__
