@@ -33,19 +33,14 @@ have their own model, but are represented via the :py:data:`ObjectVersion`
 model.
 """
 
-from __future__ import absolute_import, print_function
-
-import mimetypes
 import re
 import sys
 import uuid
 from datetime import datetime
-from functools import wraps
-from os.path import basename
-
-import six
 from flask import current_app
+from functools import wraps
 from invenio_db import db
+from os.path import basename
 from sqlalchemy.dialects import mysql
 from sqlalchemy.ext.hybrid import hybrid_property
 from sqlalchemy.orm import validates
@@ -58,7 +53,7 @@ from .errors import BucketLockedError, FileInstanceAlreadySetError, \
     MultipartInvalidChunkSize, MultipartInvalidPartNumber, \
     MultipartInvalidSize, MultipartMissingParts, MultipartNotCompleted
 from .proxies import current_files_rest
-from .utils import ENCODING_MIMETYPES, guess_mimetype
+from .utils import guess_mimetype
 
 slug_pattern = re.compile('^[a-z][a-z0-9-]+$')
 
@@ -125,16 +120,19 @@ def as_object_version_id(value):
 #
 def update_bucket_size(f):
     """Decorate to update bucket size after operation."""
+
     @wraps(f)
     def inner(self, *args, **kwargs):
         res = f(self, *args, **kwargs)
         self.bucket.size += self.file.size
         return res
+
     return inner
 
 
 def ensure_state(default_getter, exc_class, default_msg=None):
     """Create a decorator factory function."""
+
     def decorator(getter=default_getter, msg=default_msg):
         def ensure_decorator(f):
             @wraps(f)
@@ -142,8 +140,11 @@ def ensure_state(default_getter, exc_class, default_msg=None):
                 if not getter(self):
                     raise exc_class(msg) if msg else exc_class()
                 return f(self, *args, **kwargs)
+
             return inner
+
         return ensure_decorator
+
     return decorator
 
 
@@ -410,7 +411,7 @@ class Bucket(db.Model, Timestamp):
     def validate_storage_class(self, key, default_storage_class):
         """Validate storage class."""
         if default_storage_class not in \
-           current_app.config['FILES_REST_STORAGE_CLASS_LIST']:
+                current_app.config['FILES_REST_STORAGE_CLASS_LIST']:
             raise ValueError('Invalid storage class.')
         return default_storage_class
 
@@ -460,20 +461,38 @@ class Bucket(db.Model, Timestamp):
         dest_ovs = ObjectVersion.get_by_bucket(bucket=bucket,
                                                with_deleted=True)
         # transform into a dict { key: object version }
-        src_keys = {ov.key: ov for ov in src_ovs}
-        dest_keys = {ov.key: ov for ov in dest_ovs}
+        src_dict_ovs = {}
+        for ov in src_ovs:
+            # keep only the latest version of an ObjectVersion and don't
+            # override with previous
+            if ov.key not in src_dict_ovs:
+                src_dict_ovs[ov.key] = ov
 
-        for key, ov in src_keys.items():
-            if not ov.deleted:
-                if key not in dest_keys or \
-                        ov.file_id != dest_keys[key].file_id:
+        dest_dict_ovs = {}
+        for ov in dest_ovs:
+            # keep only the latest version of an ObjectVersion and don't
+            # override with previous
+            if ov.key not in dest_dict_ovs:
+                dest_dict_ovs[ov.key] = ov
+
+        for key, ov in src_dict_ovs.items():
+            key_in_dest = key in dest_dict_ovs
+            if ov.deleted:
+                if key_in_dest and not dest_dict_ovs[key].deleted:
+                    ObjectVersion.delete(bucket, key)
+            else:
+                if not key_in_dest:
                     ov.copy(bucket=bucket)
-            elif key in dest_keys and not dest_keys[key].deleted:
-                ObjectVersion.delete(bucket, key)
+                else:
+                    dest_ov = dest_dict_ovs[key]
+                    file_in_dest_differs = ov.file_id != dest_ov.file_id
+                    ov_deleted_in_dest = dest_ov.deleted
+                    if file_in_dest_differs or ov_deleted_in_dest:
+                        ov.copy(bucket=bucket)
 
         if delete_extras:
-            for key, ov in dest_keys.items():
-                if key not in src_keys:
+            for key, ov in dest_dict_ovs.items():
+                if key not in src_dict_ovs:
                     ObjectVersion.delete(bucket, key)
 
         return bucket
@@ -498,7 +517,7 @@ class Bucket(db.Model, Timestamp):
         with db.session.begin_nested():
             if location is None:
                 location = Location.get_default()
-            elif isinstance(location, six.string_types):
+            elif isinstance(location, str):
                 location = Location.get_by_name(location)
 
             obj = cls(
@@ -868,8 +887,7 @@ class FileInstance(db.Model, Timestamp):
         self.readable = readable
         self.storage_class = \
             current_app.config['FILES_REST_DEFAULT_STORAGE_CLASS'] \
-            if storage_class is None else \
-            storage_class
+            if storage_class is None else storage_class
         return self
 
 
@@ -1280,6 +1298,23 @@ class ObjectVersion(db.Model, Timestamp):
         """Check if are not equal."""
         return not self.__eq__(other=other)
 
+    # DDL string used to avoid automap in mysql until sqlalchemy 2.0
+    # https://github.com/sqlalchemy/sqlalchemy/discussions/7597
+    @classmethod
+    def ix_uq_partial_files_object_is_head_dll(cls):
+        """Return DDL instruction for ix_uq_partial_files_object_is_head."""
+        return db.DDL(
+            "CREATE UNIQUE INDEX ix_uq_partial_files_object_is_head "
+            "ON %(table)s (bucket_id, key) WHERE is_head")
+
+
+db.event.listen(
+    ObjectVersion.__table__,
+    'after_create',
+    ObjectVersion.ix_uq_partial_files_object_is_head_dll().execute_if(dialect='postgresql')
+)
+"""Create ix_uq_partial_files_object_is_head only on postgresql backend."""
+
 
 class ObjectVersionTag(db.Model):
     """Model for storing tags associated to object versions.
