@@ -8,13 +8,10 @@
 
 """Test of multipart objects."""
 
-from __future__ import absolute_import, print_function
-
 import hashlib
+from io import BytesIO
 from os.path import exists
 
-from six import BytesIO
-
 from invenio_files_rest.models import Bucket, MultipartObject, ObjectVersion, \
     Part
 
