@@ -8,15 +8,12 @@
 
 """Module test views."""
 
-from __future__ import absolute_import, print_function
-
 import errno
-from os.path import exists, join
-
 import pytest
-from fs.errors import FSError, ResourceNotFoundError
+from fs.errors import FSError, ResourceNotFound
+from io import BytesIO
 from mock import MagicMock, patch
-from six import BytesIO
+from os.path import exists, join
 
 from invenio_files_rest.models import Bucket, FileInstance, ObjectVersion
 from invenio_files_rest.tasks import migrate_file, remove_file_data, \
@@ -40,7 +37,7 @@ def test_verify_checksum(app, db, dummy_location):
     f.uri = 'invalid'
     db.session.add(f)
     db.session.commit()
-    pytest.raises(ResourceNotFoundError, verify_checksum, str(file_id),
+    pytest.raises(ResourceNotFound, verify_checksum, str(file_id),
                   throws=True)
 
     f = FileInstance.query.get(file_id)
@@ -53,7 +50,7 @@ def test_verify_checksum(app, db, dummy_location):
     f.last_check = True
     db.session.add(f)
     db.session.commit()
-    with pytest.raises(ResourceNotFoundError):
+    with pytest.raises(ResourceNotFound):
         verify_checksum(str(file_id), pessimistic=True)
     f = FileInstance.query.get(file_id)
     assert f.last_check is None
