@@ -8,14 +8,11 @@
 
 """Module test views."""
 
-from __future__ import absolute_import, print_function
-
 import json
-
 import pytest
 from flask import url_for
+from io import BytesIO
 from mock import MagicMock, patch
-from six import BytesIO
 from testutils import BadBytesIO, login_user
 
 from invenio_files_rest.models import Bucket, MultipartObject, Part
@@ -455,9 +452,7 @@ def test_post_complete_timeout(app, client, headers, bucket, multipart,
     """Test completing multipart when merge fails."""
     login_user(client, admin_user)
 
-    max_rounds = int(
-        app.config['FILES_REST_TASK_WAIT_MAX_SECONDS'] //
-        app.config['FILES_REST_TASK_WAIT_INTERVAL'])
+    max_rounds = int(app.config["FILES_REST_TASK_WAIT_MAX_SECONDS"] // app.config["FILES_REST_TASK_WAIT_INTERVAL"])
 
     # Mock celery task to emulate real usage.
     task_result = MagicMock()
