@@ -8,16 +8,8 @@
 
 """Files download/upload REST API similar to S3 for Invenio."""
 
-from __future__ import absolute_import, print_function
-
 import sys
-
-from six import BytesIO
-
-if sys.version_info.major == 2:
-    PY2 = True
-else:
-    PY2 = False
+from io import BytesIO
 
 
 def login_user(client, user):
@@ -33,17 +25,11 @@ class BadBytesIO(BytesIO):
     def __init__(self, *args, **kwargs):
         """Initialize."""
         self.called = False
-        if PY2:
-            return BytesIO.__init__(self, *args, **kwargs)
-        else:
-            return super(BadBytesIO, self).__init__(*args, **kwargs)
+        return super(BadBytesIO, self).__init__(*args, **kwargs)
 
     def read(self, *args, **kwargs):
         """Fail on second read."""
         if self.called:
             self.close()
         self.called = True
-        if PY2:
-            return BytesIO.read(self, *args, **kwargs)
-        else:
-            return super(BadBytesIO, self).read(*args, **kwargs)
+        return super(BadBytesIO, self).read(*args, **kwargs)
